'use strict';

var libQ = require('kew');
var fs=require('fs-extra');
var config = new (require('v-conf'))();
var exec = require('child_process').exec;
var execSync = require('child_process').execSync;
var Gpio = require('onoff').Gpio;


// debug
var debug = false;

module.exports = mp1Control;
function mp1Control(context) {
	var self = this;

	this.context = context;
	this.commandRouter = this.context.coreCommand;
	this.logger = this.context.logger;
	this.configManager = this.context.configManager;
}



mp1Control.prototype.onVolumioStart = function()
{
	var self = this;
	var configFile=this.commandRouter.pluginManager.getConfigurationFile(this.context,'config.json');
	this.config = new (require('v-conf'))();
	this.config.loadFile(configFile);


    return libQ.resolve();
}

mp1Control.prototype.onStart = function() {
    var self = this;
    var defer=libQ.defer();

    self.reportVolumioInitializedState();
    self.startShutdownGpioListener();


    defer.resolve();

    return defer.promise;
};

mp1Control.prototype.onStop = function() {
    var self = this;
    var defer=libQ.defer();

    defer.resolve();

    return libQ.resolve();
};

mp1Control.prototype.onRestart = function() {
    var self = this;
    // Optional, use if you need it
};


// Configuration Methods -----------------------------------------------------------------------------

mp1Control.prototype.getUIConfig = function() {
    var defer = libQ.defer();
    var self = this;

    var lang_code = this.commandRouter.sharedVars.get('language_code');

    self.commandRouter.i18nJson(__dirname+'/i18n/strings_'+lang_code+'.json',
        __dirname+'/i18n/strings_en.json',
        __dirname + '/UIConfig.json')
        .then(function(uiconf)
        {


            defer.resolve(uiconf);
        })
        .fail(function()
        {
            defer.reject(new Error());
        });

    return defer.promise;
};


mp1Control.prototype.setUIConfig = function(data) {
	var self = this;
	//Perform your installation tasks here
};

mp1Control.prototype.getConf = function(varName) {
	var self = this;
	//Perform your installation tasks here
};

mp1Control.prototype.setConf = function(varName, varValue) {
	var self = this;
	//Perform your installation tasks here
};

mp1Control.prototype.startShutdownGpioListener= function() {
    var self = this;

    var shutdownGPIO = new Gpio(426, 'in', 'both');

    shutdownGPIO.watch((err, value) => {
        if (err) {
            console.log(err)
        } else {
            if (value === 1) {
                self.executeShutdown();
            }
        }
    });
};

mp1Control.prototype.reportVolumioInitializedState = function() {
    var self = this;

    var systemReadyGPIO = new Gpio(431, 'out');

    systemReadyGPIO.write(1, err => {
        if (err) {
            self.logger.error('MP1 GPIO: Could not signal System Ready via GPIO: ' + err);
        }
    });
};

mp1Control.prototype.executeShutdown = function() {
    var self = this;

    self.logger.info('MP1 GPIO: Executing Shutdown');
    this.commandRouter.shutdown();
};